# Copyright (c) 2007 oc2pus <toni@links2linux.de>
# Copyright (c) 2007-2009 Hans de Goede <hdegoede@redhat.com>
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments to us at the above email addresses

%define _version 2008.03.30
 
Name:           Io-language
Version:        20080330
Release:        8%{?dist}.2
Summary:        Io is a small, prototype-based programming language
Group:          System Environment/Libraries
License:        BSD
URL:            http://www.iolanguage.com/
# To get this file do wget http://github.com/stevedekorte/io/tarball/%{_version}
Source0:        %{name}-%{version}.tar.gz
Patch0:         AddonBuilder_io_libdir.patch
Patch1:         Io-2007-10-10-gcc43.patch
Patch2:         Io-2007-10-10-missing-protos.patch
Patch3:         Io-language-20080330-py27.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  e2fsprogs-devel freetype-devel freeglut-devel gmp-devel
BuildRequires:  libedit-devel libevent-devel libjpeg-devel libpng-devel
BuildRequires:  libsamplerate-devel libsndfile-devel libtiff-devel
BuildRequires:  libxml2-devel mysql-devel ode-devel opensp-devel pcre-devel
BuildRequires:  portaudio-devel postgresql-devel python-devel soundtouch-devel
BuildRequires:  sqlite-devel taglib-devel ncurses-devel cairo-devel
BuildRequires:  libuuid-devel readline-devel

%description
Io is a small, prototype-based programming language. The ideas in
Io are mostly inspired by Smalltalk (all values are objects), Self
(prototype-based), NewtonScript (differential inheritance), Act1
(actors and futures for concurrency), LISP (code is a runtime
inspectable/modifiable tree) and Lua (small, embeddable).


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package graphics-and-sound
Summary:        Io graphics and sound support
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}

%description graphics-and-sound
Io graphics and sound support, this package includes IO bindings needed to
write Io programs which want to display graphics and / or produce sound
(OpenGL, Image loading, PortAudio, etc.).


%package extras
Summary:        Io extra addons
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}

%description extras
This package includes addons for Io which require additional libraries to be
installed. This includes the Python and Socket addons.


%package postgresql
Summary:        Io postgresql bindings
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}

%description postgresql
Io postgresql bindings.


%package mysql
Summary:        Io mysql bindings
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}

%description mysql
Io mysql bindings


%prep
%setup -q -n stevedekorte-io-6a5f734
%patch0 -p1
%patch1 -p1 -b .gcc43
%patch2 -p1 -b .protos
%patch3 -p1
sed -i 's|/lib/io/addons|/%{_lib}/io/addons|g' libs/iovm/io/AddonLoader.io
# building Io while Io-language-devel is installed results in binaries getting
# linked against the installed version, instead of the just build one <sigh>
if [ -f /usr/include/io/IoVM.h ]; then
  echo "Error building Io while Io-language-devel is installed does not work!"
  exit 1
fi
# libstdc++.so is searched and not found ...
sed -i -e 's|dependsOnLib("stdc++")||g' addons/SoundTouch/build.io
# remove add-ons which we do not want to build ever
rm -fr addons/AVCodec
# for %doc
mv addons/OpenGL/docs OpenGL
iconv -f MACINTOSH -t UTF8 libs/basekit/license/bsd_license.txt > license.txt
sed -i 's/\r//g' license.txt `find OpenGL -type f`
# for debuginfo
chmod -x addons/NullAddon/source/IoNullAddon.?


%build
make %{?_smp_mflags} INSTALL_PREFIX=%{_prefix} OPTIMIZE="$RPM_OPT_FLAGS" \
  DLL_COMMAND='-shared -Wl,-soname="libiovmall.so.2"'


%install
rm -rf $RPM_BUILD_ROOT
# upstreams make install installs lots of unwanted parts of the addons, so DIY
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/io/addons
mkdir -p $RPM_BUILD_ROOT%{_includedir}
install -m 755 _build/binaries/io $RPM_BUILD_ROOT%{_bindir}
install -m 755 _build/dll/libiovmall.so \
  $RPM_BUILD_ROOT%{_libdir}/libiovmall.so.2
ln -s libiovmall.so.2 $RPM_BUILD_ROOT%{_libdir}/libiovmall.so
cp -a _build/headers $RPM_BUILD_ROOT%{_includedir}/io
# install the addons
for i in addons/*; do
  # skip unbuild addons
  if [ -d $i/_build ]; then
    ADDON=`basename $i`
    mkdir -p $RPM_BUILD_ROOT%{_libdir}/io/addons/$ADDON/_build/dll
    install -m 755 $i/_build/dll/libIo$ADDON.so \
      $RPM_BUILD_ROOT%{_libdir}/io/addons/$ADDON/_build/dll
    install -p -m 644 $i/depends $RPM_BUILD_ROOT%{_libdir}/io/addons/$ADDON
    # Io doesn't find the addon if this file isn't present
    touch $RPM_BUILD_ROOT%{_libdir}/io/addons/$ADDON/build.io
  fi
done


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc license.txt
%{_bindir}/io
%{_libdir}/libiovmall.so.2
%dir %{_libdir}/io
%dir %{_libdir}/io/addons
%{_libdir}/io/addons/AsyncRequest
%{_libdir}/io/addons/BigNum
%{_libdir}/io/addons/Blowfish
%{_libdir}/io/addons/Box
%{_libdir}/io/addons/Cairo 
%{_libdir}/io/addons/CGI
%{_libdir}/io/addons/ContinuedFraction
%{_libdir}/io/addons/Curses
%{_libdir}/io/addons/DistributedObjects
%{_libdir}/io/addons/EditLine
%{_libdir}/io/addons/Flux
%{_libdir}/io/addons/Fnmatch
%{_libdir}/io/addons/LZO
%{_libdir}/io/addons/Libxml2
%{_libdir}/io/addons/Loki
%{_libdir}/io/addons/MD5
%{_libdir}/io/addons/NetworkAdapter
%{_libdir}/io/addons/NotificationCenter
%{_libdir}/io/addons/NullAddon
%{_libdir}/io/addons/Random
%{_libdir}/io/addons/Range
%{_libdir}/io/addons/Rational
%{_libdir}/io/addons/ReadLine
%{_libdir}/io/addons/Regex
%{_libdir}/io/addons/SHA1
%{_libdir}/io/addons/SQLite3
%{_libdir}/io/addons/SqlDatabase
%{_libdir}/io/addons/Syslog
%{_libdir}/io/addons/SystemCall
%{_libdir}/io/addons/Thread
%{_libdir}/io/addons/UUID
%{_libdir}/io/addons/User
%{_libdir}/io/addons/Volcano
%{_libdir}/io/addons/Zlib

%files devel
%defattr(-,root,root,-)
%doc docs/*
%{_libdir}/libiovmall.so
%{_includedir}/io

%files graphics-and-sound
%defattr(-,root,root,-)
%doc OpenGL
%{_libdir}/io/addons/Font
%{_libdir}/io/addons/Image
%{_libdir}/io/addons/LibSndFile
%{_libdir}/io/addons/OpenGL
%{_libdir}/io/addons/PortAudio
%{_libdir}/io/addons/TagLib

%files extras
%defattr(-,root,root,-)
%{_libdir}/io/addons/Python
%{_libdir}/io/addons/SampleRateConverter
%{_libdir}/io/addons/Socket
%{_libdir}/io/addons/SoundTouch

%files postgresql
%defattr(-,root,root,-)
%{_libdir}/io/addons/Postgre*

%files mysql
%defattr(-,root,root,-)
%{_libdir}/io/addons/MySQL


%changelog
* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20080330-8.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 06 2011 Adam Jackson <ajax@redhat.com> - 20080330-7.2
- Rebuild for new libpng

* Fri Oct 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 20080330-6.2
- rebuild with new gmp without compat lib

* Wed Oct 12 2011 Peter Schiffer <pschiffe@redhat.com> - 20080330-6.1
- rebuild with new gmp

* Wed Mar 23 2011 Dan Horák <dan@danny.cz> - 20080330-6
- rebuilt for mysql 5.5.10 (soname bump in libmysqlclient)

* Mon Feb 14 2011 Jon Ciesla <limb@jcomserv.net> - 20080330-5
- Rebuild for libevent.

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20080330-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jul 31 2010 Hans de Goede <hdegoede@redhat.com> - 20080330-3
- Fix compilation of python addon with python 2.7

* Fri Jul 30 2010 Hans de Goede <hdegoede@redhat.com> - 20080330-2
- Rebuild for python 2.7

* Fri Jan 15 2010 Hans de Goede <hdegoede@redhat.com> - 20080330-1
- Rebase to latest upstream release 20080330
- Bump soname because of ABI change
- Fix FTBFS (#511617)

* Fri Jan 15 2010 Caolán McNamara <caolanm@redhat.com> - 20071010-12
- Resolves: rhbz#511617 FTBFS

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20071010-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20071010-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 15 2009 Hans de Goede <hdegoede@redhat.com> - 20071010-9
- rebuild for new soundtouch

* Sat Jan 24 2009 Caolán McNamara <caolanm@redhat.com> - 20071010-8
- rebuild for dependencies

* Sun Nov 30 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 20071010-7
- Rebuild for Python 2.6

* Sun Jun 29 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 20071010-6
- Rebuild for new libevent

* Sun Mar 30 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 20071010-5
- Fix missing prototype compiler warnings

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 20071010-4
- Autorebuild for GCC 4.3

* Thu Jan 24 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 20071010-3
- Rebuild for new libevent

* Sat Jan 12 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 20071010-2
- Fix compilation with gcc 4.3
- Enable Cairo addon

* Sun Nov 11 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 20071010-1
- New (official!) upstream release 2007-10-10
- API changed, soname bumped to libiovmall.so.1

* Wed Sep 12 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 20070710-2
- Reshuffle which docs to include and in which subpackages to include them
  (bz 284151)

* Sun Sep  9 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 20070710-1
- Adapted Packman spec file for Fedora

* Sat Sep 08 2007 Toni Graffy <toni@links2linux.de> 20070528-0.pm.2
- openSUSE-10.3 build, using libode(-devel)

* Sun Jun 03 2007 Toni Graffy <toni@links2linux.de> 20070528-0.pm.1
- update to 20070528
- added patches for 64bit (thx Detlef)
- switched to portaudio

* Sun May 27 2007 Toni Graffy <toni@links2linux.de> 20070430-0.pm.1
- initial package 20070430
